smartcard.Exceptions.CardRequestTimeoutException

# ``smartcard`.`Exceptions`.`CardRequestTimeoutException``

exception documentation

`class CardRequestTimeoutException(SmartcardException):`

View In Hierarchy

Raised when a CardRequest times out.

Method | `__init__` | Undocumented

Inherited from `SmartcardException`:

Method | `__str__` | Undocumented
Instance Variable | `hresult` | Undocumented

def __init__(self, *args):
overrides `smartcard.Exceptions.SmartcardException.__init__`

Undocumented